# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim import ManagedEntity

from pyVmomi.vmodl import DynamicData

class HealthUpdate(DynamicData):
   entity: ManagedEntity
   healthUpdateInfoId: str
   id: str
   status: ManagedEntity.Status
   remediation: str



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import ManagedEntity

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.encryption import KeyProviderId
from pyVmomi.vim.encryption import KmipServerInfo

class KmipClusterInfo(DynamicData):
   class KmsManagementType(Enum):
      unknown: ClassVar['KmsManagementType'] = 'unknown'
      vCenter: ClassVar['KmsManagementType'] = 'vCenter'
      trustAuthority: ClassVar['KmsManagementType'] = 'trustAuthority'
      nativeProvider: ClassVar['KmsManagementType'] = 'nativeProvider'

   clusterId: KeyProviderId
   servers: list[KmipServerInfo] = []
   useAsDefault: bool
   managementType: Optional[str] = None
   useAsEntityDefault: list[ManagedEntity] = []
   hasBackup: Optional[bool] = None
   tpmRequired: Optional[bool] = None
   keyId: Optional[str] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import Network

from pyVmomi.eam.issue.cluster.agent import VmNotDeployed

class MissingClusterVmNetwork(VmNotDeployed):
   missingNetworks: list[Network] = []
   networkNames: list[str] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim.host import PciPassthruInfo

class SriovInfo(PciPassthruInfo):
   sriovEnabled: bool
   sriovCapable: bool
   sriovActive: bool
   numVirtualFunctionRequested: int
   numVirtualFunction: int
   maxVirtualFunctionSupported: int



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.vsan.host import DiskResult

class DiskResultEx(DiskResult):
   vsanDirectTagged: bool
   storagePoolDiskState: Optional[str] = None
   storagePoolDiskError: Optional[MethodFault] = None
   isCapacityFlash: Optional[bool] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData

class VSANWitnessHostInfo(DynamicData):
   nodeUuid: str
   faultDomainName: Optional[str] = None
   preferredFdName: Optional[str] = None
   preferredFdUuid: Optional[str] = None
   unicastAgentAddr: Optional[str] = None
   host: Optional[HostSystem] = None
   metadataMode: Optional[bool] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ClusterComputeResource

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import VsanClusterMembershipInfo
from pyVmomi.vim.host import VsanNetworkPeerHealthResult

class VsanServerClusterInfo(DynamicData):
   cluster: Optional[ClusterComputeResource] = None
   peerHealth: list[VsanNetworkPeerHealthResult] = []
   membership: Optional[VsanClusterMembershipInfo] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim.fault import OvfExport

class OvfPropertyExport(OvfExport):
   type: str
   value: str



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import DataEfficiencyConfig
from pyVmomi.vim.vsan import DataEncryptionConfig

class VsanDiskFormatConversionSpec(DynamicData):
   dataEfficiencyConfig: Optional[DataEfficiencyConfig] = None
   dataEncryptionConfig: Optional[DataEncryptionConfig] = None
   skipHostRemediation: Optional[bool] = None
   allowDataMovement: Optional[bool] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.fault import PatchNotApplicable

class PatchMissingDependencies(PatchNotApplicable):
   prerequisitePatch: list[str] = []
   prerequisiteLib: list[str] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim import KeyValue

from pyVmomi.vmodl import DynamicData

class FileShareRuntimeInfo(DynamicData):
   usedCapacity: Optional[long] = None
   hostname: Optional[str] = None
   address: Optional[str] = None
   vsanObjectUuids: list[str] = []
   accessPoints: list[KeyValue] = []
   managedBy: Optional[str] = None
   fileServerFQDN: Optional[str] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import KeyAnyValue

class VsanNetworkDiagnostics(DynamicData):
   host: HostSystem
   eventTypeId: str
   severity: str
   createdTime: datetime
   arguments: list[KeyAnyValue] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.VmomiSupport import long

from pyVmomi.vim.cluster import DasData

class DasDataSummary(DasData):
   hostListVersion: long
   clusterConfigVersion: long
   compatListVersion: long



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class FileInfo(DynamicData):
   vmPathName: Optional[str] = None
   snapshotDirectory: Optional[str] = None
   suspendDirectory: Optional[str] = None
   logDirectory: Optional[str] = None
   ftMetadataDirectory: Optional[str] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import HostSystem
from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import MaintenanceSpec

class ResourceCheckTaskDetails(DynamicData):
   task: Task
   host: Optional[HostSystem] = None
   hostUuid: Optional[str] = None
   maintenanceSpec: Optional[MaintenanceSpec] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import VsanComparator
from pyVmomi.vim import VsanJsonComparator

class VsanNestJsonComparator(VsanComparator):
   nestedComparators: list[VsanJsonComparator] = []
   conjoiner: Optional[str] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vmodl import DynamicData

class SharedGpuCapabilities(DynamicData):
   vgpu: str
   diskSnapshotSupported: bool
   memorySnapshotSupported: bool
   suspendSupported: bool
   migrateSupported: bool



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.cluster import VsanIscsiTargetCommonInfo

from pyVmomi.vim.vm import ProfileSpec

class VsanIscsiTargetSpec(VsanIscsiTargetCommonInfo):
   storagePolicy: Optional[ProfileSpec] = None
   newAlias: Optional[str] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.pbm import ServerObjectRef

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.pbm.profile import ProfileId

class QueryProfileResult(DynamicData):
   object: ServerObjectRef
   profileId: list[ProfileId] = []
   fault: Optional[MethodFault] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import VsanDownloadItem

class VsanHostCimProviderInfo(DynamicData):
   cimProviderSupported: Optional[bool] = None
   installedCIMProvider: Optional[str] = None
   cimProviderOnHcl: list[str] = []
   cimProviderLinksOnHcl: list[VsanDownloadItem] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim.host import AuthenticationStoreInfo

class AuthenticationStore(ManagedObject):
   @property
   def info(self) -> AuthenticationStoreInfo: ...



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vApp import IPAssignmentInfo
from pyVmomi.vim.vApp import OvfSectionSpec
from pyVmomi.vim.vApp import ProductSpec
from pyVmomi.vim.vApp import PropertySpec

class VmConfigSpec(DynamicData):
   product: list[ProductSpec] = []
   property: list[PropertySpec] = []
   ipAssignment: Optional[IPAssignmentInfo] = None
   eula: list[str] = []
   ovfSection: list[OvfSectionSpec] = []
   ovfEnvironmentTransport: list[str] = []
   installBootRequired: Optional[bool] = None
   installBootStopDelay: Optional[int] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import DistributedVirtualSwitch

from pyVmomi.vim.event import ChangesInfoEventArgument
from pyVmomi.vim.event import DvsEvent

class DvsReconfiguredEvent(DvsEvent):
   configSpec: DistributedVirtualSwitch.ConfigSpec
   configChanges: Optional[ChangesInfoEventArgument] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class VsanHclMinFwConstraint(DynamicData):
   vcgId: int
   vcgLink: str
   model: str
   partner: str
   partNumber: Optional[str] = None
   release: str
   firmware: str



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.VmomiSupport import long

from pyVmomi.vim.option import LongOption

from pyVmomi.vim.vm.device import VirtualDeviceOption

class VirtualNVDIMMOption(VirtualDeviceOption):
   capacityInMB: LongOption
   growable: bool
   hotGrowable: bool
   granularityInMB: long



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim.cns import FileCreateSpec

from pyVmomi.vim.vsan import FileShareNetPermission

class VSANFileCreateSpec(FileCreateSpec):
   softQuotaInMb: Optional[long] = None
   permission: list[FileShareNetPermission] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vmodl import DynamicData

class VsanCapability(DynamicData):
   target: Optional[ManagedObject] = None
   capabilities: list[str] = []
   statuses: list[str] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.sms.provider import Provider

from pyVmomi.vim.vm.replication import FaultDomainId

class FaultDomainInfo(FaultDomainId):
   name: Optional[str] = None
   description: Optional[str] = None
   storageArrayId: Optional[str] = None
   children: list[FaultDomainId] = []
   provider: Optional[Provider] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim import Datastore
from pyVmomi.vim import HostSystem

from pyVmomi.vim.fault import ResourceInUse

class QuiesceDatastoreIOForHAFailed(ResourceInUse):
   host: HostSystem
   hostName: str
   ds: Datastore
   dsName: str



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.event import ClusterEvent

class HostMonitoringStateChangedEvent(ClusterEvent):
   state: str
   prevState: Optional[str] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class RepairTimerInfo(DynamicData):
   maxTimeToRepair: int
   minTimeToRepair: int
   objectCount: int
   objectCountWithRepairTimer: Optional[int] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import HistoryCollector

from pyVmomi.vim.event import Event

class EventHistoryCollector(HistoryCollector):
   @property
   def latestPage(self) -> list[Event]: ...
   @property
   def initialized(self) -> Optional[bool]: ...

   def ReadNext(self, maxCount: int) -> list[Event]: ...
   def ReadPrev(self, maxCount: int) -> list[Event]: ...



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim import Datastore

from pyVmomi.eam.issue import NoAgentVmDatastore

class NoCustomAgentVmDatastore(NoAgentVmDatastore):
   customAgentVmDatastore: list[Datastore] = []
   customAgentVmDatastoreName: list[str] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import VsanHostIoInsightInfo

class VsanIoInsightInstance(DynamicData):
   runName: str
   state: Optional[str] = None
   startTime: Optional[datetime] = None
   endTime: Optional[datetime] = None
   hostsIoInsightInfo: list[VsanHostIoInsightInfo] = []
   hostUuids: list[str] = []
   vmUuids: list[str] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn

from pyVmomi.VmomiSupport import ManagedObject

class SessionManager(ManagedObject):
   def LoginByToken(self, delegatedTokenXml: str) -> NoReturn: ...
   def Logout(self) -> NoReturn: ...



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim.fault import CpuIncompatible

class CpuIncompatible1ECX(CpuIncompatible):
   sse3: bool
   pclmulqdq: bool
   ssse3: bool
   sse41: bool
   sse42: bool
   aes: bool
   other: bool
   otherOnly: bool



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.cluster import VsanDataDrivenAPIAction
from pyVmomi.vim.cluster import VsanHealthActionBase
from pyVmomi.vim.cluster import VsanHealthConfirmationDialog

class VsanHealthDataDrivenAction(VsanHealthActionBase):
   apiAction: VsanDataDrivenAPIAction
   confirmation: Optional[VsanHealthConfirmationDialog] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class PropertyInfo(DynamicData):
   key: int
   classId: Optional[str] = None
   instanceId: Optional[str] = None
   id: Optional[str] = None
   category: Optional[str] = None
   label: Optional[str] = None
   type: Optional[str] = None
   typeReference: Optional[str] = None
   userConfigurable: Optional[bool] = None
   defaultValue: Optional[str] = None
   value: Optional[str] = None
   description: Optional[str] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ResourceConfigSpec

from pyVmomi.vmodl import DynamicData

class SystemResourceInfo(DynamicData):
   key: str
   config: Optional[ResourceConfigSpec] = None
   child: list[SystemResourceInfo] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim import ElementDescription
from pyVmomi.vim import TypeDescription

from pyVmomi.vmodl import DynamicData

class ScheduledTaskDescription(DynamicData):
   class SchedulerDetail(TypeDescription):
      frequency: str

   action: list[TypeDescription] = []
   schedulerInfo: list[SchedulerDetail] = []
   state: list[ElementDescription] = []
   dayOfWeek: list[ElementDescription] = []
   weekOfMonth: list[ElementDescription] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm import ProfileSpec

class VsanPerfsvcConfig(DynamicData):
   enabled: bool
   profile: Optional[ProfileSpec] = None
   diagnosticMode: Optional[bool] = None
   verboseMode: Optional[bool] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ExtendedElementDescription

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.profile import ParameterMetadata

class PolicyOptionMetadata(DynamicData):
   id: ExtendedElementDescription
   parameter: list[ParameterMetadata] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import binary

from pyVmomi.vim.vm.device import VirtualDevice

class VirtualTPM(VirtualDevice):
   endorsementKeyCertificateSigningRequest: list[binary] = []
   endorsementKeyCertificate: list[binary] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class VsanHealthConfirmationDialog(DynamicData):
   title: str
   subTitle: Optional[str] = None
   content: str
   agreeLabel: Optional[str] = None
   closeLabel: Optional[str] = None
   isWarning: Optional[bool] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm.customization import Password

class GuiUnattended(DynamicData):
   password: Optional[Password] = None
   timeZone: int
   autoLogon: bool
   autoLogonCount: int



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData

class VsanVibSpec(DynamicData):
   host: HostSystem
   metaUrl: Optional[str] = None
   metaSha1Sum: Optional[str] = None
   vibUrl: str
   vibSha1Sum: str



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import RuntimeFault

class LicenseAssignmentFailed(RuntimeFault):
   class Reason(Enum):
      keyEntityMismatch: ClassVar['Reason'] = 'keyEntityMismatch'
      downgradeDisallowed: ClassVar['Reason'] = 'downgradeDisallowed'
      inventoryNotManageableByVirtualCenter: ClassVar['Reason'] = 'inventoryNotManageableByVirtualCenter'
      hostsUnmanageableByVirtualCenterWithoutLicenseServer: ClassVar['Reason'] = 'hostsUnmanageableByVirtualCenterWithoutLicenseServer'

   reason: Optional[str] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.vm import PciPassthroughInfo
from pyVmomi.vim.vm import SriovDevicePoolInfo

class SriovInfo(PciPassthroughInfo):
   virtualFunction: bool
   pnic: Optional[str] = None
   devicePool: Optional[SriovDevicePoolInfo] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ManagedEntity

from pyVmomi.vim.view import ManagedObjectView

class InventoryView(ManagedObjectView):
   def OpenFolder(self, entity: list[ManagedEntity]) -> list[ManagedEntity]: ...
   def CloseFolder(self, entity: list[ManagedEntity]) -> list[ManagedEntity]: ...



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ManagedEntity

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.fault import DvsFault

class ConflictingConfiguration(DvsFault):
   class Config(DynamicData):
      entity: Optional[ManagedEntity] = None
      propertyPath: str

   configInConflict: list[Config] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import LifecycleFaultDomainDetails
from pyVmomi.vim.vsan import LifecycleWitnessDetails

class LifecycleConfigDetails(DynamicData):
   clusterType: str
   faultDomainsDetails: list[LifecycleFaultDomainDetails] = []
   witnessHostsDetails: list[LifecycleWitnessDetails] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.vm.replication import FaultDomainId

class QueryReplicationPeerResult(DynamicData):
   sourceDomain: FaultDomainId
   targetDomain: list[FaultDomainId] = []
   error: list[MethodFault] = []
   warning: list[MethodFault] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vmodl import DynamicData

from pyVmomi.pbm.capability import PropertyInstance

class ConstraintInstance(DynamicData):
   propertyInstance: list[PropertyInstance] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import HostBusAdapter
from pyVmomi.vim.host import NvmeController

class NvmeTopology(DynamicData):
   class Interface(DynamicData):
      key: str
      adapter: HostBusAdapter
      connectedController: list[NvmeController] = []

   adapter: list[Interface] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim.vm.device import VirtualDevice

class VirtualCdrom(VirtualDevice):
   class IsoBackingInfo(VirtualDevice.FileBackingInfo):
      pass

   class PassthroughBackingInfo(VirtualDevice.DeviceBackingInfo):
      exclusive: bool

   class RemotePassthroughBackingInfo(VirtualDevice.RemoteDeviceBackingInfo):
      exclusive: bool

   class AtapiBackingInfo(VirtualDevice.DeviceBackingInfo):
      pass

   class RemoteAtapiBackingInfo(VirtualDevice.RemoteDeviceBackingInfo):
      pass



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim.event import VmEvent

class VmWwnChangedEvent(VmEvent):
   oldNodeWwns: list[long] = []
   oldPortWwns: list[long] = []
   newNodeWwns: list[long] = []
   newPortWwns: list[long] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanHealthDataDrivenAction

class VsanClusterHealthResultRow(DynamicData):
   values: list[str] = []
   nestedRows: list[VsanClusterHealthResultRow] = []
   actions: list[VsanHealthDataDrivenAction] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan.host import VsanObjectSyncState
from pyVmomi.vim.vsan.host import VsanSyncingObjectRecoveryDetails

class VsanSyncingObjectQueryResult(DynamicData):
   totalObjectsToSync: Optional[long] = None
   totalBytesToSync: Optional[long] = None
   totalRecoveryETA: Optional[long] = None
   objects: list[VsanObjectSyncState] = []
   syncingObjectRecoveryDetails: Optional[VsanSyncingObjectRecoveryDetails] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class HostBusAdapter(DynamicData):
   key: Optional[str] = None
   device: str
   bus: int
   status: str
   model: str
   driver: Optional[str] = None
   pci: Optional[str] = None
   storageProtocol: Optional[str] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData

class VSANStretchedClusterFaultDomainConfig(DynamicData):
   firstFdName: str
   firstFdHosts: list[HostSystem] = []
   secondFdName: str
   secondFdHosts: list[HostSystem] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.pbm.profile import ProfileId

from pyVmomi.vmodl.fault import SecurityError

class NoPermission(SecurityError):
   class EntityPrivileges(DynamicData):
      profileId: Optional[ProfileId] = None
      privilegeIds: list[str] = []

   missingPrivileges: list[EntityPrivileges] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim.vm.device import VirtualDevice

class VirtualFloppy(VirtualDevice):
   class ImageBackingInfo(VirtualDevice.FileBackingInfo):
      pass

   class DeviceBackingInfo(VirtualDevice.DeviceBackingInfo):
      pass

   class RemoteDeviceBackingInfo(VirtualDevice.RemoteDeviceBackingInfo):
      pass



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.event import PermissionEvent
from pyVmomi.vim.event import RoleEventArgument

class PermissionUpdatedEvent(PermissionEvent):
   role: RoleEventArgument
   propagate: bool
   prevRole: Optional[RoleEventArgument] = None
   prevPropagate: Optional[bool] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vmodl import KeyAnyValue

from pyVmomi.vmodl.fault import NotEnoughLicenses

class LicenseDowngradeDisallowed(NotEnoughLicenses):
   edition: str
   entityId: str
   features: list[KeyAnyValue] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import HostSystem
from pyVmomi.vim import ResourcePool

from pyVmomi.vim.cluster import Action

class InitialPlacementAction(Action):
   targetHost: HostSystem
   pool: Optional[ResourcePool] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.cluster import VsanIscsiLUNCommonInfo

from pyVmomi.vim.vm import ProfileSpec

class VsanIscsiLUNSpec(VsanIscsiLUNCommonInfo):
   storagePolicy: Optional[ProfileSpec] = None
   newLunId: Optional[int] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData

class VsanAttachToSrOperation(DynamicData):
   task: Optional[Task] = None
   success: Optional[bool] = None
   timestamp: Optional[datetime] = None
   srNumber: str



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ElementDescription

from pyVmomi.vim.host import CpuIdInfo
from pyVmomi.vim.host import FeatureCapability
from pyVmomi.vim.host import FeatureMask

from pyVmomi.vim.vm import FeatureRequirement

class EVCMode(ElementDescription):
   guaranteedCPUFeatures: list[CpuIdInfo] = []
   featureCapability: list[FeatureCapability] = []
   featureMask: list[FeatureMask] = []
   featureRequirement: list[FeatureRequirement] = []
   vendor: str
   track: list[str] = []
   vendorTier: int



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import FileSystemVolume

class LocalFileSystemVolume(FileSystemVolume):
   class Specification(DynamicData):
      device: str
      localPath: str

   device: str



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.vm.device import VirtualDevice

class VirtualController(VirtualDevice):
   busNumber: int
   device: list[int] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.option import IntOption

from pyVmomi.vim.vm.device import VirtualControllerOption

class VirtualNVMEControllerOption(VirtualControllerOption):
   numNVMEDisks: IntOption
   sharing: list[str] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

class MemoryTierInfo(DynamicData):
   name: str
   type: str
   flags: list[str] = []
   internalFlags: list[str] = []
   size: long



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.event import DvsEvent
from pyVmomi.vim.event import HostEventArgument

class DvsHostStatusUpdated(DvsEvent):
   hostMember: HostEventArgument
   oldStatus: Optional[str] = None
   newStatus: Optional[str] = None
   oldStatusDetail: Optional[str] = None
   newStatusDetail: Optional[str] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim import ElementDescription

from pyVmomi.vmodl import DynamicData

class AuthorizationDescription(DynamicData):
   privilege: list[ElementDescription] = []
   privilegeGroup: list[ElementDescription] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import HostSystem
from pyVmomi.vim import VirtualMachine

class OverheadMemoryManager(ManagedObject):
   def LookupVmOverheadMemory(self, vm: VirtualMachine, host: HostSystem) -> long: ...



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim.view import View

class ManagedObjectView(View):
   @property
   def view(self) -> list[ManagedObject]: ...



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn

from pyVmomi.VmomiSupport import ManagedObject

class HistoryCollector(ManagedObject):
   @property
   def filter(self) -> object: ...

   def SetLatestPageSize(self, maxCount: int) -> NoReturn: ...
   def Rewind(self) -> NoReturn: ...
   def Reset(self) -> NoReturn: ...
   def Remove(self) -> NoReturn: ...



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import FileShareSnapshotConfig

class FileShareSnapshot(DynamicData):
   config: Optional[FileShareSnapshotConfig] = None
   creationTime: Optional[datetime] = None
   usedCapacity: Optional[long] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ClusterComputeResource

from pyVmomi.vmodl import DynamicData

class VSANStretchedClusterHostVirtualApplianceStatus(DynamicData):
   vcCluster: Optional[ClusterComputeResource] = None
   isVirtualApp: Optional[bool] = None
   vcClusters: list[ClusterComputeResource] = []
   isVirtualAppValid: Optional[bool] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import HostSystem

class StorageQueryManager(ManagedObject):
   def QueryHostsWithAttachedLun(self, lunUuid: str) -> list[HostSystem]: ...



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.profile import ApplyProfile

class ApplyProfileProperty(DynamicData):
   propertyName: str
   array: bool
   profile: list[ApplyProfile] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim.scheduler import DailyTaskScheduler

class WeeklyTaskScheduler(DailyTaskScheduler):
   sunday: bool
   monday: bool
   tuesday: bool
   wednesday: bool
   thursday: bool
   friday: bool
   saturday: bool



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

class VsanVcsaDeploymentProgress(DynamicData):
   phase: str
   progressPct: long
   message: str
   success: bool
   error: Optional[MethodFault] = None
   updateCounter: long
   taskId: Optional[str] = None
   vm: Optional[VirtualMachine] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.pbm import ExtendedElementDescription

from pyVmomi.vmodl import DynamicData

class ResourceUtilization(DynamicData):
   name: ExtendedElementDescription
   description: ExtendedElementDescription
   availableBefore: Optional[long] = None
   availableAfter: Optional[long] = None
   total: Optional[long] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.eam.fault import EamFault

class InvalidUrl(EamFault):
   url: str
   malformedUrl: bool
   unknownHost: bool
   connectionRefused: bool
   responseCode: Optional[int] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.eam import Agent

from pyVmomi.vim import HostSystem

from pyVmomi.eam.issue import AgencyIssue

class AgentIssue(AgencyIssue):
   agent: Agent
   agentName: str
   host: HostSystem
   hostName: str



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

class UpdateVirtualMachineFilesResult(DynamicData):
   class FailedVmFileInfo(DynamicData):
      vmFile: str
      fault: MethodFault

   failedVmFile: list[FailedVmFileInfo] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim import SharesInfo

from pyVmomi.vmodl import DynamicData

class ResourceAllocationInfo(DynamicData):
   reservation: Optional[long] = None
   expandableReservation: Optional[bool] = None
   limit: Optional[long] = None
   shares: Optional[SharesInfo] = None
   overheadLimit: Optional[long] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class MultipathStateInfo(DynamicData):
   class Path(DynamicData):
      name: str
      pathState: str

   path: list[Path] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import RuntimeFault

class ThirdPartyLicenseAssignmentFailed(RuntimeFault):
   class Reason(Enum):
      licenseAssignmentFailed: ClassVar['Reason'] = 'licenseAssignmentFailed'
      moduleNotInstalled: ClassVar['Reason'] = 'moduleNotInstalled'

   host: HostSystem
   module: str
   reason: Optional[str] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.encryption import CryptoKeyId

class CryptoKeyResult(DynamicData):
   keyId: CryptoKeyId
   success: bool
   reason: Optional[str] = None
   fault: Optional[MethodFault] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import MaintenanceSpec

class ResourceCheckSpec(DynamicData):
   operation: str
   entities: list[str] = []
   maintenanceSpec: Optional[MaintenanceSpec] = None
   parent: Optional[Task] = None



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicArray
from pyVmomi.vmodl import DynamicData

class XvcQueryCriteria(DynamicData):
   property: str
   operator: Optional[str] = None
   comparableValue: Optional[object] = None
   comparableList: Optional[DynamicArray] = None
   ignoreCase: Optional[bool] = None
